# Generated by Django 3.2.16 on 2024-01-17 00:12

import django.core.serializers.json
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0011_synceddata'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='synceddata',
            name='data',
        ),
        migrations.AddField(
            model_name='synceddata',
            name='oauth_state',
            field=models.JSONField(decoder=django.core.serializers.json.DjangoJSONEncoder, default=list, encoder=django.core.serializers.json.DjangoJSONEncoder),
        ),
    ]
