# Generated by Django 3.2.16 on 2024-01-17 00:58

import django.core.serializers.json
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0013_rename_oauth_state_synceddata_data'),
    ]

    operations = [
        migrations.AlterField(
            model_name='synceddata',
            name='data',
            field=models.JSONField(default=list, encoder=django.core.serializers.json.DjangoJSONEncoder),
        ),
    ]
