# Generated by Django 3.2.16 on 2023-10-10 19:14

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0008_remove_constancesetting_last_reported'),
    ]

    operations = [
        migrations.CreateModel(
            name='TemplateStatSummary',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_synced', models.DateTimeField(db_index=True)),
                ('tenant', models.CharField(db_index=True, max_length=200)),
                ('object_pk', models.IntegerField()),
                ('object_content_type_name', models.CharField(max_length=100)),
                ('created', models.DateTimeField()),
                ('region', models.CharField(max_length=10)),
                ('name', models.CharField(max_length=250)),
                ('key', models.CharField(max_length=250)),
                ('extends', models.CharField(blank=True, default='', max_length=250)),
                ('usage_total', models.IntegerField()),
                ('usage_this_year', models.IntegerField()),
                ('usage_last_year', models.IntegerField()),
                ('libraries_loaded', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=250), blank=True, default=list, size=None)),
                ('deprecated_functions', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=250), blank=True, default=list, size=None)),
                ('is_active', models.BooleanField()),
            ],
            options={
                'db_table': 'workforce"."template_stat_summary',
                'managed': True,
            },
        ),
    ]
