# Generated by Django 3.2.16 on 2023-10-26 14:39

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0009_templatestatsummary'),
    ]

    operations = [
        migrations.AlterField(
            model_name='usagemetrics',
            name='for_date',
            field=models.DateField(db_index=True, default=datetime.date.today),
            preserve_default=False,
        ),
    ]
