# Generated by Django 3.2.16 on 2024-06-23 21:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptionmanager', '0009_subscriptionsummary_billing_entity_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscriptionsummary',
            name='superseded_by_guid',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='subscriptionsummary',
            name='superseded_subscription_contract_value',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name='subscriptionsummary',
            name='superseded_subscription_guid',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='subscriptionsummary',
            name='superseded_subscription_upgrade_or_downgrade_amount',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True),
        ),
    ]
