# Generated by Django 3.2.16 on 2023-07-04 15:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0005_auto_20230606_0658'),
    ]

    operations = [
        migrations.AddField(
            model_name='usagemetrics',
            name='for_date',
            field=models.DateField(null=True),
        ),
    ]
