# Generated by Django 4.1.5 on 2023-01-12 00:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = []

    operations = [
        migrations.RunSQL("""
        create schema if not exists vitally
        """),
    ]