# Generated by Django 3.2.16 on 2024-06-23 09:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptionmanager', '0008_auto_20240531_1445'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscriptionsummary',
            name='billing_entity_name',
            field=models.CharField(default='', max_length=250),
            preserve_default=False,
        ),
    ]
