# Generated by Django 3.2.16 on 2023-07-04 23:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0006_usagemetrics_for_date'),
    ]

    operations = [
        migrations.AlterField(
            model_name='serverusage',
            name='for_date',
            field=models.DateField(db_index=True),
        ),
        migrations.AlterField(
            model_name='serverusage',
            name='tenant',
            field=models.CharField(db_index=True, max_length=200),
        ),
        migrations.AlterField(
            model_name='usagemetrics',
            name='for_date',
            field=models.DateField(db_index=True, null=True),
        ),
        migrations.AddIndex(
            model_name='usagemetrics',
            index=models.Index(fields=['tenant', 'count_name', '-for_date'], name='usage_metrics_date_btree'),
        ),
    ]
