# Generated by Django 3.2.16 on 2024-05-31 14:45

from decimal import Decimal
from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptionmanager', '0007_auto_20240516_0257'),
    ]

    operations = [
        migrations.CreateModel(
            name='NetPaidMRRValue',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_synced', models.DateTimeField()),
                ('entity_name', models.CharField(max_length=200)),
                ('customer_account_code', models.CharField(max_length=200)),
                ('date', models.DateField()),
                ('local_account_code', models.CharField(max_length=100)),
                ('local_account_name', models.CharField(max_length=300)),
                ('subtotal', models.DecimalField(decimal_places=2, default=Decimal('0.00'), max_digits=10)),
                ('currency', models.CharField(max_length=3)),
            ],
            options={
                'db_table': 'subscriptionmanager"."net_paid_mrr_value',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.AddField(
            model_name='addonsummary',
            name='last_synced',
            field=models.DateTimeField(default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='plansummary',
            name='last_synced',
            field=models.DateTimeField(default=django.utils.timezone.now),
            preserve_default=False,
        ),
    ]
